Index: webrtc/modules/video_capture/linux/video_capture_linux.h |
diff --git a/webrtc/modules/video_capture/linux/video_capture_linux.h b/webrtc/modules/video_capture/linux/video_capture_linux.h |
index 8172eb8d2a890b740b151ff1dfb7c1d63f453e21..72266643c6178627b79b5d0ea8678944382f4924 100644 |
--- a/webrtc/modules/video_capture/linux/video_capture_linux.h |
+++ b/webrtc/modules/video_capture/linux/video_capture_linux.h |
@@ -11,6 +11,8 @@ |
#ifndef WEBRTC_MODULES_VIDEO_CAPTURE_MAIN_SOURCE_LINUX_VIDEO_CAPTURE_LINUX_H_ |
#define WEBRTC_MODULES_VIDEO_CAPTURE_MAIN_SOURCE_LINUX_VIDEO_CAPTURE_LINUX_H_ |
+#include <memory> |
+ |
#include "webrtc/base/platform_thread.h" |
#include "webrtc/common_types.h" |
#include "webrtc/modules/video_capture/video_capture_impl.h" |
@@ -39,8 +41,8 @@ private: |
bool AllocateVideoBuffers(); |
bool DeAllocateVideoBuffers(); |
- // TODO(pbos): Stop using scoped_ptr and resetting the thread. |
- rtc::scoped_ptr<rtc::PlatformThread> _captureThread; |
+ // TODO(pbos): Stop using unique_ptr and resetting the thread. |
+ std::unique_ptr<rtc::PlatformThread> _captureThread; |
CriticalSectionWrapper* _captureCritSect; |
int32_t _deviceId; |